@@ -2,7 +2,7 @@ import numpy as np
 from scipy.stats import chi2
 from pathlib import Path
 import re
-from nmrtoolbox.util import Range, ROI, AxisData, TableData, PeakOutsideOfMaskError, ParsePeakTableError, is_iterable
+from nmrtoolbox.util import Range, ROI, AxisData, SpectrumData, PeakOutsideOfMaskError, ParsePeakTableError, is_iterable
 from nmrtoolbox.mask import Mask
 
 
@@ -23,7 +23,7 @@ class Peak:
 
         # this is an AxisData object
         if isinstance(axis_property, AxisData):
-            self.axis_property = axis_property
+            self.axis = axis_property
         else:
             raise TypeError('axis_property must be AxisData type')
 
@@ -43,25 +43,6 @@ class Peak:
                 pass
             self.prop[p] = v
 
-    def axis_keys(self):
-        """Get the axis keys"""
-        return self.axis_property.axis_keys()
-
-    def axis_dimensions(self):
-        """Get the axis dimensions"""
-        return self.axis_property.get_field(name='dimension')
-
-    def axis2dimension(self, axis):
-        """Convert an axis (e.g. 'HN') to a dimension (e.g. 'X')"""
-        try:
-            return self.axis_property.get_field(name='dimension', axis=axis)[0]
-        except KeyError as e:
-            raise KeyError(e)
-
-    def num_dims(self):
-        """Number of dimensions"""
-        return len(self.axis_keys())
-
     def get_par(self, par, axis_dimensions='all'):
         """
         Get value of specified parameter for specified axes.
@@ -78,13 +59,13 @@ class Peak:
 
             # determine which axes to query
             if axis_dimensions == 'all':
-                axis_dimensions = self.axis_dimensions()
+                axis_dimensions = self.axis.dimensions()
             if isinstance(axis_dimensions, str):
                 axis_dimensions = [axis_dimensions]
 
             # perform substitutions of axis names into parameter name as needed
             for axis in axis_dimensions:
-                if axis not in self.axis_dimensions():
+                if axis not in self.axis.dimensions():
                     raise KeyError(f'invalid axis: {axis}')
                 par_set.append(par.replace('*', axis))
 
@@ -128,11 +109,11 @@ class Peak:
         if not isinstance(roi, ROI):
             raise TypeError('region of interest must be provided as ROI class object')
 
-        if roi.axis_keys() != self.axis_property.axis_keys():
+        if roi.keys() != self.axis.keys():
             raise ValueError('the current peak and the given ROI do not have same set of axes')
 
-        for axis in self.axis_keys():
-            dimension = self.axis2dimension(axis)
+        for axis in self.axis.keys():
+            dimension = self.axis.axis2dimension(axis)
             roi_range = roi.get_field(name='roi', axis=axis)[0]
             peak_ppm = self.get_par(f'{dimension}_PPM')
             if not roi_range.contains(peak_ppm):
@@ -146,16 +127,13 @@ class Peak:
         if not isinstance(mask, Mask):
             raise TypeError('empty region of spectrum must be provided as Mask class object')
 
-        # TODO:
-        #  the Mask.axis_labels property is np.ndarray, so "==" is done pairwise and we need .all()
-        #  maybe upgrade Mask class to use AxisData and then call axis_keys() method here
-        if not (mask.axis_labels == self.axis_keys()).all():
+        if mask.axis.keys() != self.axis.keys():
             raise ValueError('mask and peak have different axes')
 
         try:
             return mask.ppm_in_mask(
                 peak_ppm=self.get_par('*_PPM'),
-                peak_axis_property=self.axis_property,
+                peak_axis_property=self.axis,
                 box_radius=box_radius,
             )
         except PeakOutsideOfMaskError as e:
@@ -211,14 +189,10 @@ class PeakTable:
         #   - labels (e.g.H1, N15)
         #   - num_pts
         #   - ppm_range (from ppm_high, ppm_low)
-        # TODO:
-        #  consider using axis labels as the keys instead of X, Y, Z
-        #  this would simplify how data objects are validated as compatible (currently looking
-        #  for 'label' in the AxisData, but could just be using the AxisData keys)
-        self.axis_property = AxisData()
+        self.axis = AxisData()
 
         # global properties that describe the collection of peaks
-        self.table_property = TableData()
+        self.table_property = SpectrumData()
 
         # subclasses will each call _parse_file() to populate self.peaks and self.axis_property
         # subclasses can optionally include "pre" and "post" tasks in their __init__ to perform before/after parsing
@@ -272,11 +246,11 @@ class PeakTable:
                 raise KeyError(e)
 
         elif isinstance(carrier_frequency, AxisData):
-            if carrier_frequency.axis_keys() != self.axis_keys():
+            if carrier_frequency.keys() != self.axis.keys():
                 raise AttributeError('The axes for the given carrier frequency data dot match those of the peak table')
             # extract ONLY the carrier frequency values from the carrier_frequency AxisData object
             # this object could contain other properties that we don't want
-            self.axis_property.set_data(carrier_frequency.get('carrier_frequency'))
+            self.axis.set_data(carrier_frequency.get('carrier_frequency'))
 
         else:
             msg = 'define carrier frequency by providing a list of lists: [key, cf, cf_units]'
@@ -296,7 +270,7 @@ class PeakTable:
                 else:
                     raise ValueError(f'do not recognize units for carrier frequency: {cf_units}.  must use "Hz" or "MHz"')
 
-                self.axis_property.set(
+                self.axis.set(
                     axis=key,
                     name='carrier_frequency',
                     value=cf_hz,
@@ -321,8 +295,8 @@ class PeakTable:
         except KeyError as e:
             raise KeyError(e)
 
-        for axis, cf in zip(self.axis_property.axis_keys(), carrier):
-            self.axis_property.set(
+        for axis, cf in zip(self.axis.keys(), carrier):
+            self.axis.set(
                 axis=axis,
                 name='carrier_frequency',
                 value=cf,
@@ -332,16 +306,16 @@ class PeakTable:
     def _set_peak_positions_hz(self):
         """Use ppm peak positions and provided carrier frequencies to determine peak positions in Hz"""
 
-        for axis in self.axis_keys():
-            dimension = self.axis2dimension(axis)
+        for axis in self.axis.keys():
+            dimension = self.axis.axis2dimension(axis)
 
             try:
                 peak_ppm = self.get_par(par=f'{dimension}_PPM')
             except KeyError:
                 raise KeyError(f'missing peak PPM data for axis: {axis}')
             try:
-                unit = self.axis_property.get_field(name='carrier_frequency', axis=axis, field='unit')[0]
-                value = self.axis_property.get_field(name='carrier_frequency', axis=axis, field='value')[0]
+                unit = self.axis.get_field(name='carrier_frequency', axis=axis, field='unit')[0]
+                value = self.axis.get_field(name='carrier_frequency', axis=axis, field='value')[0]
                 if unit.lower() == 'hz':
                     cf_mhz = value / 1e6
                 elif unit.lower() == 'mhz':
@@ -469,25 +443,6 @@ class PeakTable:
         """Reorder the peak list by HEIGHT (positive down to negative)"""
         self.peaks = sorted(self.peaks, key=lambda x: x.prop['HEIGHT'], reverse=True)
 
-    def axis_keys(self):
-        """Get the axis keys"""
-        return self.axis_property.axis_keys()
-
-    def num_dims(self):
-        """Number of dimensions"""
-        return len(self.axis_keys())
-
-    def axis_dimensions(self):
-        """Get the axis dimensions"""
-        return self.axis_property.get_field(name='dimension')
-
-    def axis2dimension(self, axis):
-        """Convert an axis (e.g. 'HN') to a dimension (e.g. 'X')"""
-        try:
-            return self.axis_property.get_field(name='dimension', axis=axis)[0]
-        except KeyError as e:
-            raise KeyError(e)
-
     def determine_outliers(self, chi2prob):
         # get full width of each recovered peak in points along each of its dimensions
         w = self.get_par('*W')
@@ -583,18 +538,18 @@ class PeakTablePipe(PeakTable):
                                 continue
                             elif info[1].endswith('_AXIS'):
                                 axis = info[2]
-                                self.axis_property.set(
+                                self.axis.set(
                                     axis=axis,
                                     name='dimension',
                                     value=info[1].split('_')[0],
                                 )
-                                self.axis_property.set(
+                                self.axis.set(
                                     axis=axis,
                                     name='num_pts',
                                     value=int(info[4]),
                                     unit='count'
                                 )
-                                self.axis_property.set(
+                                self.axis.set(
                                     axis=axis,
                                     name='range',
                                     value=Range(
@@ -633,7 +588,7 @@ class PeakTablePipe(PeakTable):
                         self.peaks.append(Peak(
                             prop_list=self.VARS,
                             val_list=line.split(),
-                            axis_property=self.axis_property,
+                            axis_property=self.axis,
                         ))
 
 
@@ -661,8 +616,8 @@ class PeakTablePipeRec(PeakTablePipe):
         except KeyError as e:
             raise KeyError(e)
 
-        for axis, LW in zip(self.axis_property.axis_keys(), LW_list):
-            self.axis_property.set(
+        for axis, LW in zip(self.axis.keys(), LW_list):
+            self.axis.set(
                 axis=axis,
                 name='LW',
                 value=LW,
@@ -727,11 +682,11 @@ class PeakTablePipeInj(PeakTablePipe):
     def _set_maxLW(self):
         # parse through the tokens to find maxLW values for each axis
         tokens = self.genSimTab.split()
-        for axis in self.axis_keys():
-            dimension = self.axis2dimension(axis)
+        for axis in self.axis.keys():
+            dimension = self.axis.axis2dimension(axis)
             try:
                 idx = tokens.index(f'-{dimension.lower()}wMax')
-                self.axis_property.set(
+                self.axis.set(
                     axis=axis,
                     name='maxLW',
                     value=float(tokens[idx + 1]),
