@@ -77,7 +77,7 @@ class roc:
             try:
                 self.injected_peaks = PeakTablePipeInj(
                     file=injected_table,
-                    carrier_frequency=self.recovered_peaks.axis_property)
+                    carrier_frequency=self.recovered_peaks.axis)
             except FileNotFoundError as e:
                 raise FileNotFoundError(e)
             except ParsePeakTableError as e:
@@ -97,7 +97,7 @@ class roc:
             except ValueError as e:
                 raise ValueError(f'failed to read ROI - {e}')
 
-            if roi_object.axis_keys() != self.recovered_peaks.axis_keys():
+            if roi_object.keys() != self.recovered_peaks.axis.keys():
                 raise ValueError('ROI axes do not match those of recovered peak table')
 
             # after validation - capture the roi
@@ -115,7 +115,7 @@ class roc:
         # Get the max LW values used by genSimTab and then expand by a lw_scalar to define the distance along each axis
         # used to define if a recovered peak is within the accepted range of an injected peak to be considered a match.
         self.lw_scalar = lw_scalar
-        self.peak_range_hz = np.array(self.injected_peaks.axis_property.get_field('maxLW')) * self.lw_scalar
+        self.peak_range_hz = np.array(self.injected_peaks.axis.get_field('maxLW')) * self.lw_scalar
 
         # ================================================
         # run the reduce commands (if any parameters are not given to roc, then they are None and reduce skips them)
@@ -161,14 +161,14 @@ class roc:
 
     def _validate_input(self):
         # sometimes proton is labeled as 1H or HN, so standardize on the more common HN
-        if '1H' in self.recovered_peaks.axis_keys() and 'HN' in self.injected_peaks.axis_keys():
-            self.recovered_peaks.axis_property['HN'] = self.recovered_peaks.axis_property.pop('1H')
+        if '1H' in self.recovered_peaks.axis.keys() and 'HN' in self.injected_peaks.axis.keys():
+            self.recovered_peaks.axis['HN'] = self.recovered_peaks.axis.pop('1H')
 
-        if self.injected_peaks.axis_keys() != self.recovered_peaks.axis_keys():
+        if self.injected_peaks.axis.keys() != self.recovered_peaks.axis.keys():
             raise ValueError('The injected and recovered peak tables have different axis labels.')
 
         if hasattr(self, 'roi'):
-            if self.injected_peaks.axis_keys() != self.roi.axis_keys():
+            if self.injected_peaks.axis.keys() != self.roi.keys():
                 raise ValueError(
                     'The ROI definition does not have the same axis labels as the peak injected and recovered peak tables.')
 
@@ -306,7 +306,7 @@ class roc:
             n, bins, patches = ax.hist([p[dim] for p in peak_width_all], bins=20)
             ax.set_xlim(.9*np.min(bins), 1.1*np.max(bins))
             ax.set_ylim(-0.1*np.max(n), 1.1*np.max(n))
-            ax.set_title(self.recovered_peaks.axis_keys()[dim])
+            ax.set_title(self.recovered_peaks.axis.keys()[dim])
 
             # row 1: peak widths for KEEPERS on dimension
             ax = axs[1, dim]
@@ -360,7 +360,7 @@ class roc:
     def plot_peaks(self, dir_out=os.getcwd(), file_basename='peaks', show_figure=False):
 
         # TODO: this axis and dimension handling is very confusing
-        num_dim = len(self.injected_peaks.axis_keys())
+        num_dim = len(self.injected_peaks.axis.keys())
         temp_slice_axes = combinations(list(range(1, num_dim + 1)), 2)
         slice_axes = [i for i in temp_slice_axes]
 
@@ -381,8 +381,8 @@ class roc:
 
             fig, ax = plt.subplots()
             fig.subplots_adjust(right=0.75)
-            plt.xlabel(f"{self.recovered_peaks.axis_keys()[xdim]} Domain [ppm]")
-            plt.ylabel(f"{self.recovered_peaks.axis_keys()[ydim]} Domain [ppm]")
+            plt.xlabel(f"{self.recovered_peaks.axis.keys()[xdim]} Domain [ppm]")
+            plt.ylabel(f"{self.recovered_peaks.axis.keys()[ydim]} Domain [ppm]")
             plt.scatter(trueRecov_xdim_ppm, trueRecov_ydim_ppm,
                         c='#C5C9C7', marker='s', label='True Recovered')
             plt.scatter(falseRecov_xdim_ppm, falseRecov_ydim_ppm,
